package org.springblade.modules.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.entity.*;
import org.springblade.modules.mapper.BzdzMapper;
import org.springblade.modules.service.BzdzService;
import org.springblade.modules.vo.*;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

@Service
public class BzdzServiceImpl extends ServiceImpl<BzdzMapper, BzdzEntity> implements BzdzService {
	@Override
	public List<LdBzdzVO> getJzwList(Map<String, Object> params) {
		return baseMapper.getJzwList(params);
	}

	@Override
	public List<DyVO> getDyList(Map<String, Object> params) {
		return baseMapper.getDyList(params);
	}

	@Override
	public List<LcVO> getLcList(Map<String, Object> params) {
		return baseMapper.getLcList(params);
	}

	@Override
	public List<FjVO> getFjList(Map<String, Object> params) {
		return baseMapper.getFjList(params);
	}

	@Override
	public BzdzEntity bzdzDetail(Map<String, Object> params) {
		return baseMapper.bzdzDetail(params);
	}

	@Override
	public boolean fzUpdate(BzdzEntity bzdzEntity) {
		return baseMapper.fzUpdate(bzdzEntity);
	}

	@Override
	public FwFzEntity selectByFzId(Long fzid) {
		return baseMapper.selectByFzId(fzid);
	}

	@Override
	public void fzlsSave(BzdzEntity fz) {
		baseMapper.fzlsSave(fz);
	}

	@Override
	public List<FzLsVO> selectFzLs(Long fzid) {
		return baseMapper.selectFzLs(fzid);
	}

	@Override
	public List<SyjzryVO> syrkDetail(String dzbm) {
		List<SyjzryVO> list = baseMapper.syrkDetail(dzbm);
		if(list.size()>0){
			for (int i = 0; i < list.size(); i++) {
				SyjzryVO syjzryVOs = list.get(i);
				String dzbms = syjzryVOs.getDzbm();
				syjzryVOs.setDzXz(baseMapper.getFwxzByRkDzxx(dzbms));
			}
		}
		return list;
	}

	@Override
	public List<SyjzryVO> syrkLsDetail(String dzbm) {
		return baseMapper.syrkLsDetail(dzbm);
	}

	@Override
	public FwInfoEntity getFwIsExist(FwInfoEntity fwInfo) {
		return baseMapper.getFwIsExist(fwInfo);
	}

	@Override
	public void czrkZx(SyrkzxVO syrkzxVO) {
		baseMapper.czrkZx(syrkzxVO);
	}

	@Override
	public void jwrkZx(SyrkzxVO syrkzxVO) {
		baseMapper.jwrkZx(syrkzxVO);
	}

	@Override
	public void jzrkZx(SyrkzxVO syrkzxVO) {
		baseMapper.jzrkZx(syrkzxVO);
	}

	@Override
	public void wlrkZx(SyrkzxVO syrkzxVO) {
		baseMapper.wlrkZx(syrkzxVO);
	}

	@Override
	public void zzrkZx(SyrkzxVO syrkzxVO) {
		baseMapper.zzrkZx(syrkzxVO);
	}

	@Override
	public void ryLsSave(RyLsEntity ryLs) {
		baseMapper.ryLsSave(ryLs);
	}

	@Override
	public SydwEntity selectSydwByDzbm(String dzbm) {
		return baseMapper.selectSydwByDzbm(dzbm);
	}

	@Override
	public BzdzEntity selectFw(String dzbm) {
		return baseMapper.selectFw(dzbm);
	}

	@Override
	public SydwEntity sydwDetail(SydwEntity sydwEntity) {
		return baseMapper.sydwDetail(sydwEntity);
	}

	@Override
	public List<CyryEntity> selectCyryByDzbm(String tyshxydm) {
		List<CyryEntity> list = baseMapper.selectCyryByDzbm(tyshxydm);
		if (list.size() > 0) {
			for (CyryEntity cyry:list) {
				String dzbm = cyry.getXz();
				cyry.setXz(baseMapper.getFwxzByRkDzxx(dzbm));
			}
		}
		return list;
	}

	@Override
	public boolean fzzx(FwFzEntity fwFzEntity) {
		return baseMapper.fzzx(fwFzEntity);
	}

	@Override
	public void fzzxlsSave(FwFzEntity fwFzEntity) {
		baseMapper.fzzxlsSave(fwFzEntity);
	}

	@Override
	public boolean saveCyry(CyryEntity cyryEntity) {
		return baseMapper.saveCyry(cyryEntity);
	}

	@Override
	public void updateSydwzx(SydwEntity sydw, Long userId) {
		baseMapper.updateSydwzx(sydw, userId);
	}

	@Override
	public void updateCyryzx(SydwEntity sydw, Long userId) {
		baseMapper.updateCyryzx(sydw, userId);
	}

	@Override
	public List<SydwEntity> sydwLsjl(String dzbm) {
		return baseMapper.sydwLsjl(dzbm);
	}

	@Override
	public List<CyryEntity> cyryLsjl(String dzbm) {
		return baseMapper.cyryLsjl(dzbm);
	}

	@Override
	public FwFzEntity selectXxBySfzh(String fzSfzh) {
		return baseMapper.selectXxBySfzh(fzSfzh);
	}

	@Override
	public Long selectCzrkId(RyCzrkEntity czrkEntity) {
		return baseMapper.selectCzrkId(czrkEntity);
	}

	@Override
	public Long selectJwrkId(RyJwrkEntity jwrkEntity) {
		return baseMapper.selectJwrkId(jwrkEntity);
	}

	@Override
	public Long selectJzrkId(RyJzrkEntity jzrkEntity) {
		return baseMapper.selectJzrkId(jzrkEntity);
	}

	@Override
	public Long selectWlrkId(RyWlrkEntity wlrkEntity) {
		return baseMapper.selectWlrkId(wlrkEntity);
	}

	@Override
	public Long selectZzrkId(RyZzrkEntity zzrkEntity) {
		return baseMapper.selectZzrkId(zzrkEntity);
	}

	@Override
	public void updateFwRyzxById(SyrkzxVO syrkzxVO) {
		baseMapper.updateFwRyzxById(syrkzxVO);
	}

	@Override
	public UserVO djxx(Long userId) {
		return baseMapper.djxx(userId);
	}

	@Override
	public List<CyryEntity> selectCyrylsByDzbm(String tyshxydm) {
		List<CyryEntity> list = baseMapper.selectCyrylsByDzbm(tyshxydm);
		if (list.size() > 0) {
			for (CyryEntity cyry:list) {
				String dzbm = cyry.getXz();
				cyry.setXz(baseMapper.getFwxzByRkDzxx(dzbm));
			}
		}
		return list;
	}

	@Override
	public List<String> selectFwInfo(String deptId) {
		return baseMapper.selectFwInfo(deptId);
	}

	@Override
	public DwdzVO selectDwDz(String dz) {
		return baseMapper.selectDwDz(dz);
	}

	@Override
	public BzdzEntity selectSyrkBySfzh(BzdzEntity bzdzEntity, String deptId) {
		return baseMapper.selectSyrkBySfzh(bzdzEntity, deptId);
	}

	@Override
	public BzdzEntity selectPcsByCreateDept(Long createDept) {
		return baseMapper.selectPcsByCreateDept(createDept);
	}

	@Override
	public BzdzEntity selectCzrkBySfzh(String rySfzh) {
		return baseMapper.selectCzrkBySfzh(rySfzh);
	}

	@Override
	public BzdzEntity selectJwrkByZjhm(String ryZjhm) {
		return baseMapper.selectJwrkByZjhm(ryZjhm);
	}

	@Override
	public BzdzEntity selectJzrkBySfzh(String rySfzh) {
		return baseMapper.selectJzrkBySfzh(rySfzh);
	}

	@Override
	public BzdzEntity selectWlrkBySfzh(String rySfzh) {
		return baseMapper.selectWlrkBySfzh(rySfzh);
	}

	@Override
	public BzdzEntity selectZzrkBySfzh(String rySfzh) {
		return baseMapper.selectZzrkBySfzh(rySfzh);
	}

	@Override
	public void czrkUpdate(BzdzEntity bzdzEntity) {
		baseMapper.czrkUpdate(bzdzEntity);
	}

	@Override
	public void jwrkUpdate(BzdzEntity bzdzEntity) {
		baseMapper.jwrkUpdate(bzdzEntity);
	}

	@Override
	public void jzrkUpdate(BzdzEntity bzdzEntity) {
		baseMapper.jzrkUpdate(bzdzEntity);
	}

	@Override
	public void wlrkUpdate(BzdzEntity bzdzEntity) {
		baseMapper.wlrkUpdate(bzdzEntity);
	}

	@Override
	public void zzrkUpdate(BzdzEntity bzdzEntity) {
		baseMapper.zzrkUpdate(bzdzEntity);
	}

	@Override
	public void updatePcsCzrk(SyjzryVO syjzryVO) {
		baseMapper.updatePcsCzrk(syjzryVO);
	}

	@Override
	public void updatePcsJwrk(SyjzryVO syjzryVO) {
		baseMapper.updatePcsJwrk(syjzryVO);
	}

	@Override
	public void updatePcsJzrk(SyjzryVO syjzryVO) {
		baseMapper.updatePcsJzrk(syjzryVO);
	}

	@Override
	public void updatePcsWlrk(SyjzryVO syjzryVO) {
		baseMapper.updatePcsWlrk(syjzryVO);
	}

	@Override
	public void updatePcsZzrk(SyjzryVO syjzryVO) {
		baseMapper.updatePcsZzrk(syjzryVO);
	}

	@Override
	public String selectDept(String updateDept) {
		return baseMapper.selectDept(updateDept);
	}

	@Override
	public void updateFwRy(FwRyEntity fwRyEntity) {
		baseMapper.updateFwRy(fwRyEntity);
	}

	@Override
	public Dept selectDeptById(String deptId) {
		return baseMapper.selectDeptById(deptId);
	}

	@Override
	public BzdzEntity selectRyxxBySfzh(String rySfzh) {
		return baseMapper.selectRyxxBySfzh(rySfzh);
	}
}
